# How to contribute

We welcome all contributions to MDAnalysis TUI!

Contributions can take many forms, such as:

* sharing bug reports or feature requests through the [Issue Tracker](https://github.com/p-j-smith/mda-tui/issues)
* asking or answering questions, or otherwise joining in on discussions
* adding bug fixes, new features, or otherwise improving the code
* adding or improving documentation

The second two options both involve making a [pull request](https://github.com/p-j-smith/mda-tui/pulls) .

There are many existing guides on how to make a contribution to an open
source project on GitHub. In short, the steps are to:

  * Ensure that you have a [GitHub account](https://github.com/signup/free)
  * [Fork](https://help.github.com/articles/fork-a-repo/) the repository into your own account
  * On your local machine, [clone](https://help.github.com/articles/cloning-a-repository/) your fork
  * Create a development environment from source, following the Installation from source instructions
  * Create a new branch off the `main` branch with a meaningful name (e.g. ``git checkout -b fix-issue-39``)
  * Add your modifications to the code or documentation
  * Add tests if modifying the code
  * Commit and push changes to GitHub, and open a pull request

Guides such as the [MDAnalysis User Guide](https://userguide.mdanalysis.org/stable/contributing.html)
have been written in much more detail to go through these steps more thoroughly.
We strongly encourage you to check those for help, and we welcome any questions.
Thank you for your contribution!
